@@ -21,9 +21,9 @@ import functools
 
 
 class Status(Enum):
-    error = -1
-    empty = 0
-    valid = 1
+    ERROR = -1
+    EMPTY = 0
+    VALID = 1
 
 
 @dataclass
@@ -39,9 +39,9 @@ class MiData:
 
     def __post_init__(self):
         if len(self.records):
-            self.status = Status.valid
+            self.status = Status.VALID
         else:
-            self.status = Status.empty
+            self.status = Status.EMPTY
 
 @dataclass
 class MiError:
@@ -53,7 +53,7 @@ class MiError:
     '''
     code: str
     description: str
-    status: Status = field(default=status.Error, init=False)
+    status: Status = field(default=Status.ERROR, init=False)
 
 
 @functools.cache
